### Name: writeFITSim
### Title: Write a FITS image (multi-dimensional numeric array) to disk
### Aliases: writeFITSim writeFITSim16i
### Keywords: file

### ** Examples


## Make data array with axis information, write to disk
X <- matrix(1:15, ncol = 3)
writeFITSim(X, file = "test.fits", c1 = "Test FITS file",
            crpix = c(1,1), crvaln = c(10, 100), cdeltn = c(8, 2),
            ctypen = c("Distance", "Time"),
            cunitn = c("Furlongs", "Fortnights"))
## Read back in and display
Z <-  readFITS("test.fits")
ax1 <- axVec(1, Z$axDat)          # Make axis vector for image
ax2 <- axVec(2, Z$axDat)
xlab <- Z$axDat$ctype[1]          
ylab <- paste(Z$axDat$ctype[2], " [", Z$axDat$cunit[2], "]", sep = "")
image(ax1, ax2, Z$imDat, xlab = xlab, ylab = ylab)
summary(Z)
Z$axDat                           # Display data frame with axis data
Z$hdr[1:10]                       # Header sample
Z$hdr[which(Z$hdr=="BITPIX")+1]   # BITPIX value from header
unlink("test.fits")

### 3-dimensional array example
## Write sample file
X <- array(1:210, dim = c(10, 7, 3))
writeFITSim(X, "test.fits")
## Read back in and display plane 2, no axis scale markings
Z <-  readFITS("test.fits")
dim(Z$imDat[,,2])
image(Z$imDat[,,2], xaxt = "n", yaxt = "n")
summary(Z)
print(Z$axDat)
unlink("test.fits")

### Note: either of the writeFITSim() calls here could be replaced 
###       with writeFITSim16i() calls with the identical argument.



